TextMatch class
Represents a matched flagged word or phrase within the scanned text.
Constructors
Properties
- category → FilterCategory
-
The category of the flagged content.
final
- endIndex → int
-
The ending index (exclusive) of the match in the original text.
final
- filterName → String
-
The name of the filter that produced this match.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- matched → String
-
The original flagged word or phrase from the input text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIndex → int
-
The absolute starting index of the match in the original text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override